@@ -1,5 +1,4 @@
-from inspect import signature
-
+from ..compat import PY3, signature
 from ..typecheck import compatible
 
 
@@ -18,48 +17,6 @@ def test_compatible_when_equal():
     assert compatible(bar, bar)
 
 
-def test_allow_new_params_with_defaults():
-
-    @signature
-    def iface(a, b, c):  # pragma: nocover
-        pass
-
-    @signature
-    def impl(a, b, c, d=3, e=5, *, f=5):  # pragma: nocover
-        pass
-
-    assert compatible(impl, iface)
-    assert not compatible(iface, impl)
-
-
-def test_allow_reorder_kwonlys():
-
-    @signature
-    def foo(a, b, c, *, d, e, f):  # pragma: nocover
-        pass
-
-    @signature
-    def bar(a, b, c, *, f, d, e):  # pragma: nocover
-        pass
-
-    assert compatible(foo, bar)
-    assert compatible(bar, foo)
-
-
-def test_allow_default_changes():
-
-    @signature
-    def foo(a, b, c=3, *, d=1, e, f):  # pragma: nocover
-        pass
-
-    @signature
-    def bar(a, b, c=5, *, f, e, d=12):  # pragma: nocover
-        pass
-
-    assert compatible(foo, bar)
-    assert compatible(bar, foo)
-
-
 def test_disallow_new_or_missing_positionals():
 
     @signature
@@ -101,15 +58,19 @@ def test_disallow_reorder_positionals():
     assert not compatible(bar, foo)
 
 
-def test_disallow_kwonly_to_positional():
+def test_allow_new_params_with_defaults_no_kwonly():
 
     @signature
-    def foo(a, *, b):  # pragma: nocover
+    def iface(a, b, c):  # pragma: nocover
         pass
 
     @signature
-    def bar(a, b):  # pragma: nocover
+    def impl(a, b, c, d=3, e=5, f=5):  # pragma: nocover
         pass
 
-    assert not compatible(foo, bar)
-    assert not compatible(bar, foo)
+    assert compatible(impl, iface)
+    assert not compatible(iface, impl)
+
+
+if PY3:  # pragma: nocover
+    from ._py3_typecheck_tests import *
